summaryrefslogtreecommitdiff
path: root/include/configs/cobra5272.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/configs/cobra5272.h')
-rw-r--r--include/configs/cobra5272.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/configs/cobra5272.h b/include/configs/cobra5272.h
index 52000b58b73..65b9074cd9c 100644
--- a/include/configs/cobra5272.h
+++ b/include/configs/cobra5272.h
@@ -30,7 +30,7 @@
*/
#define CONFIG_SYS_CLK 66000000
-#define CONFIG_SYS_SDRAM_SIZE 16 /* SDRAM size in MB */
+#define CFG_SYS_SDRAM_SIZE 16 /* SDRAM size in MB */
/* ---
* Define baudrate for UART1 (console output, tftp, ...)
@@ -152,9 +152,9 @@ enter a valid image address in flash */
/*-----------------------------------------------------------------------
* Start addresses for the final memory configuration
* (Set up by the startup code)
* Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
*/
-#define CONFIG_SYS_SDRAM_BASE 0x00000000
+#define CFG_SYS_SDRAM_BASE 0x00000000
/*
*-------------------------------------------------------------------------
@@ -162,7 +162,7 @@ enter a valid image address in flash */
*-----------------------------------------------------------------------
*/
-/* #define CONFIG_SYS_SDRAM_SIZE 16 */
+/* #define CFG_SYS_SDRAM_SIZE 16 */
/*
*-----------------------------------------------------------------------
@@ -186,8 +186,8 @@ enter a valid image address in flash */
#define DCACHE_STATUS (CONFIG_SYS_INIT_RAM_ADDR + \
CONFIG_SYS_INIT_RAM_SIZE - 4)
#define CONFIG_SYS_ICACHE_INV (CF_CACR_CINV | CF_CACR_INVI)
-#define CONFIG_SYS_CACHE_ACR0 (CONFIG_SYS_SDRAM_BASE | \
- CF_ADDRMASK(CONFIG_SYS_SDRAM_SIZE) | \
+#define CONFIG_SYS_CACHE_ACR0 (CFG_SYS_SDRAM_BASE | \
+ CF_ADDRMASK(CFG_SYS_SDRAM_SIZE) | \
CF_ACR_EN | CF_ACR_SM_ALL)
#define CONFIG_SYS_CACHE_ICACR (CF_CACR_CENB | CF_CACR_CINV | \
CF_CACR_DISD | CF_CACR_INVI | \
@@ -152,9 +152,9 @@ enter a valid image address in flash */
* Start addresses for the final memory configuration
* (Set up by the startup code)
- * Please note that CONFIG_SYS_SDRAM_BASE _must_ start at 0
+ * Please note that CFG_SYS_SDRAM_BASE _must_ start at 0
*/